==> pyside_1.1.0.orig.tar.bz2: pyside-qt4.7+1.1.0/doc/codesnippets/doc/src/snippets/qfontdatabase/main.cpp <==
/############################################################################
##
## Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
## Contact: Nokia Corporation (qt-info@nokia.com)
##
## This file is part of the documentation of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial Usage
## Licensees holding valid Qt Commercial licenses may use self file in
## accordance with the Qt Commercial License Agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and Nokia.
##
## GNU Lesser General Public License Usage
## Alternatively, self file may be used under the terms of the GNU Lesser
## General Public License version 2.1 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL included in the
## packaging of self file.  Please review the following information to
## ensure the GNU Lesser General Public License version 2.1 requirements
## will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
##
## In addition, as a special exception, Nokia gives you certain
## additional rights. These rights are described in the Nokia Qt LGPL
## Exception version 1.0, included in the file LGPL_EXCEPTION.txt in self
## package.
##
## GNU General Public License Usage
## Alternatively, self file may be used under the terms of the GNU
## General Public License version 3.0 as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL included in the
## packaging of self file.  Please review the following information to
## ensure the GNU General Public License version 3.0 requirements will be
## met: http://www.gnu.org/copyleft/gpl.html.
##
## If you are unsure which license is appropriate for your use, please
## contact the sales department at http://www.qtsoftware.com/contact.
## $QT_END_LICENSE$
##
############################################################################/

//! [0]
    database = QFontDatabase()
    fontTree = QTreeWidget()
    fontTree.setColumnCount(2)
    fontTree.setHeaderLabels(QStringList() << "Font" << "Smooth Sizes")

    for family in database.families():
        familyItem = QTreeWidgetItem(fontTree)
        familyItem.setText(0, family)

        for style in database.styles(family):
            styleItem = QTreeWidgetItem(familyItem)
            styleItem.setText(0, style)

            sizes = 0
            for points in database.smoothSizes(family, style):
                sizes += QString.number(points) + " "

            styleItem.setText(1, sizes.trimmed())
        
//! [0] //! [1]
    
//! [1]

==> pyside_1.2.1.orig.tar.bz2: pyside-qt4.8+1.2.1/doc/codesnippets/doc/src/snippets/qfontdatabase/main.cpp <==
/############################################################################
##
## Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
## Contact: http://www.qt-project.org/legal
##
## This file is part of the documentation of the Qt Toolkit.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and Digia.  For licensing terms and
## conditions see http://qt.digia.com/licensing.  For further information
## use the contact form at http://qt.digia.com/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 2.1 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU Lesser General Public License version 2.1 requirements
## will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
##
## In addition, as a special exception, Digia gives you certain additional
## rights.  These rights are described in the Digia Qt LGPL Exception
## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3.0 as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU General Public License version 3.0 requirements will be
## met: http://www.gnu.org/copyleft/gpl.html.
##
##
## $QT_END_LICENSE$
##
############################################################################/

//! [0]
    database = QFontDatabase()
    fontTree = QTreeWidget()
    fontTree.setColumnCount(2)
    fontTree.setHeaderLabels(QStringList() << "Font" << "Smooth Sizes")

    for family in database.families():
        familyItem = QTreeWidgetItem(fontTree)
        familyItem.setText(0, family)

        for style in database.styles(family):
            styleItem = QTreeWidgetItem(familyItem)
            styleItem.setText(0, style)

            sizes = 0
            for points in database.smoothSizes(family, style):
                sizes += QString.number(points) + " "

            styleItem.setText(1, sizes.trimmed())
        
//! [0] //! [1]
    
//! [1]
